.. traceAnalysis documentation master file, created by
   sphinx-quickstart on Fri Jan 10 16:54:21 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Papylio documentation
===========================

Papylio is a python package for single-molecule fluorescence data analysis.

Current functionality
---------------------

- Molecule localization
- Emission channel alignment
- Fluorescence intensity and FRET trace extraction
- Trace selection
- Trace classification
- Kinetic parameter extraction
- SPARXS analysis


.. toctree::
    :maxdepth: 2
    :hidden:

    Installation
    Getting started
    User guide <user_guide/index>
    Examples <examples/index>
    SPARXS <SPARXS/index>
    GUI
    API reference
    Contributing
